@@ -11,7 +11,7 @@ class TextRCNNClassifier(DeepClassifier, TextRNN):
                  classes,
                  is_multilabel=True,
                  segmenter='jieba',
-                 max_length=100,
+                 max_sequence_length=100,
                  embed_size=100,
                  num_rnn_layers=1,
                  rnn_hidden_size=512,
@@ -40,7 +40,7 @@ class TextRCNNClassifier(DeepClassifier, TextRNN):
         super().__init__(classes,
                          is_multilabel=is_multilabel,
                          segmenter=segmenter,
-                         max_length=max_length,
+                         max_sequence_length=max_sequence_length,
                          embed_size=embed_size,
                          algorithm='text_rcnn',
                          num_rnn_layers=num_rnn_layers,
